@@ -1,4 +1,4 @@
-from performance_data.BaseCollect import BaseCollect
+from .BaseCollect import BaseCollect
 
 
 class Win(BaseCollect):
